@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "yaml-pro" "1.3.3"
+(define-package "yaml-pro" "20250817.452"
   "Parser-aided YAML editing features."
   '((emacs "26.1")
     (yaml  "0.5.1"))
